clear all
set matsize 10000
set maxvar 10000
set more off

cd "\IRI data"
	
*** Program to examine heterogeneity by private vs. branded

	import delimited "iri_rev_sales_private.csv"

	merge m:1 iri_key using entries_wide_11.dta
	drop _merge
	
** Create WM post-entry and entry week indicator

	rename wmid* idwm*
	forvalues i=1/19 {
		capture gen wm`i' = (weekid >= week`i')
		capture gen enter`i' = (weekid == week`i')
		capture replace dis`i' = 0 if wm`i' == 0
		}
	egen wm = rowtotal(wm*)
	egen enter = rowtotal(enter*)
	
	encode market, gen(mkt)
	
** Setup
	rename iri_key stores
	xtset stores weekid
	
/*	egen dis = rowtotal(dis*)
	forvalues i=1/19 {
		capture gen dis`i'_2 = dis`i'^2
		capture gen dis`i'_3 = dis`i'^3
		}
	egen dis_sq = rowtotal(dis*_2)
	egen dis_cu = rowtotal(dis*_3)
	drop dis*_2 dis*_3
*/	
	* Distance spline
	forvalues s=1/1 {
		forvalues i=1/24 {
			capture gen I_`i'_`s' = (dis`i' <= `s' & dis`i' > 0 )
			}
		egen wm_`s' = rowtotal(I_*_`s')
		drop I*
		}

	forvalues s=3(2)11 {
		local s0 = `s'-2
		forvalues i=1/24 {
			capture gen I_`i'_`s' = (dis`i' <= `s' & dis`i' > `s0' )
			}
		egen wm_`s' = rowtotal(I_*_`s')
		drop I*
		}
	
** Merge in store names
	rename stores iri_key
	merge m:1 iri_key using store_names.dta
	drop if _merge == 2
	drop _merge
	rename iri_key stores	
	
	* Merge in chain info
	merge m:1 name using chain.dta
	drop _merge
	
	gen missing_chain = (chainid ==.)
	
	replace firmtype = 3 if firmtype == 4
	encode name, gen(chain)
	replace chain = 0 if missing_chain == 1
	
** Treatment groups
	by stores, sort: egen treat_nwm = max(wm)
	by stores, sort: egen wm0 = min(wm)
	
	gen wm_diff = treat_nwm - wm0
	
** Create variables

	merge m:1 monthid using cpi.dta
	drop _merge

	foreach kind in private brand {
		foreach var in carbbev coffee coldcer fzdinent fzpizza hotdog margbutr mayo mustketc peanbutr saltsnck soup spagsauc sugarsub yogurt {
			gen `var'_`kind'_price = (`var'_`kind'_rev / `var'_`kind'_sales) / cpi * 100
			drop `var'_`kind'_rev `var'_`kind'_sales
			}
		}
		
	* Fix outlier
	qui sum fzdinent_brand_price, detail
	replace fzdinent_brand_price = . if fzdinent_brand_price > `r(p99)'
	
	foreach kind in private brand {
		foreach var in carbbev coffee coldcer fzdinent fzpizza hotdog margbutr mayo mustketc peanbutr saltsnck soup spagsauc sugarsub yogurt {
			gen logp_`kind'_`var' = log(`var'_`kind'_price)
			}
		}
		
	compress

keep stores weekid wm wm_* mkt chain* enter logp* firmtype treat_nwm week*

** Stack datasets
	
	preserve
	foreach var in carbbev coffee coldcer fzdinent fzpizza hotdog margbutr mayo mustketc peanbutr saltsnck soup spagsauc sugarsub yogurt {
		keep stores weekid wm wm_* mkt chain* enter firmtype logp*_`var' treat_nwm week*
		gen category = "`var'"
		rename logp_brand_`var' logp_brand
		rename logp_private_`var' logp_private
		save `var'.dta, replace
		restore, preserve
		}
	restore, not
		
	clear
	foreach var in carbbev coffee coldcer fzdinent fzpizza hotdog margbutr mayo mustketc peanbutr saltsnck soup spagsauc sugarsub yogurt {
		append using `var'.dta
		erase `var'.dta
		}
		
	encode category, gen(cat)
	egen storecat = group(stores cat)
	xtset storecat weekid
		
** Regressions
	cd "\Results"

	foreach var of varlist logp* {
		reg `var' enter wm_1-wm_11 i.cat i.weekid, cluster(stores)
			outreg2 using final_`var', excel
		reg `var' enter wm_1-wm_11 i.cat i.mkt i.weekid, cluster(stores)
			outreg2 using final_`var', excel
		reg `var' enter wm_1-wm_11 i.cat i.chain i.mkt i.weekid, cluster(stores)
			outreg2 using final_`var', excel
		reg `var' enter wm_1-wm_11 i.cat i.chain i.mkt i.treat_nwm i.weekid, cluster(stores)
			outreg2 using final_`var', excel
		xtreg `var' enter wm_1-wm_11 i.cat i.weekid, fe i(stores) cluster(stores)
			outreg2 using final_`var', excel
		xtreg `var' enter wm_1-wm_11 i.weekid, fe i(storecat) cluster(stores)
			outreg2 using final_`var', excel
		xtreg `var' enter wm_1-wm_11 i.weekid i.cat#c.weekid i.cat#c.weekid#c.weekid, fe i(storecat) cluster(stores)
			outreg2 using final_`var', excel
		xtreg `var' enter wm_1-wm_11 i.weekid i.cat#c.weekid i.cat#c.weekid#c.weekid i.mkt#c.weekid i.mkt#c.weekid#c.weekid, fe i(storecat) cluster(stores)
			outreg2 using final_`var', excel
		xtreg `var' enter wm_1-wm_11 i.weekid i.cat#c.weekid i.cat#c.weekid#c.weekid i.mkt#c.weekid i.mkt#c.weekid#c.weekid i.treat_nwm#c.weekid i.treat_nwm#c.weekid#c.weekid, fe i(storecat) cluster(stores)
			outreg2 using final_`var', excel
		}
		
	* Homogenous effect at less than 5 miles
	gen wm_lt5 = wm_1+wm_3+wm_5
	foreach var of varlist logp* {
	reghdfe `var' enter wm_lt5 i.cat#c.weekid i.cat#c.weekid#c.weekid i.mkt#c.weekid i.mkt#c.weekid#c.weekid i.treat_nwm#c.weekid i.treat_nwm#c.weekid#c.weekid, a(storecat weekid) cluster(stores) keepsing
		outreg2 using final_`var', excel
		}
		

		